import React, { useCallback, useState } from "react";
import { UploadOutlined } from "@ant-design/icons";
import { Upload, Button, message } from "antd";
import { uploadFile } from "@/services/rotationChart";

export default (props) => {
  const { value, onChange, preview, multiple = false, ...inputProps } = props;
  const [loading, setLoading] = useState(false);

  const onUpload = useCallback(
    (e) => {
      const { files } = e.target;
      if (!files || files.length < 1) return;

      setLoading(true);
      const data = new FormData();
      data.append("file", files[0]);

      uploadFile(data)
        .then((res) => {
          setLoading(false);
          if (typeof onChange === "function") {
            if (multiple) {
              onChange([...(value || []), { fileAddr: res.url }]);
            } else {
              onChange(value);
            }
          }
        })
        .catch((err) => {
          setLoading(false);
          // onError(err);
        });
    },
    [onChange]
  );

  const onClick = () => {
    const input = document.createElement("input");
    input.type = "file";
    Object.assign(input, inputProps);
    input.addEventListener("change", onUpload);
    // input.removeEventListener('change', onUpload);
    input.click();
  };

  const uploadProps = {
    name: "file",
    fileList:
      value?.map((x, index) => ({
        uid: `uid-${index}`,
        name: x?.url?.substring(x?.url?.lastIndexOf("/") + 1),
        status: "dome",
        ...x,
      })) || [],
    customRequest: ({ file, onError, onSuccess }) => {
      const data = new FormData();
      data.append("file", file);
      setLoading(true);
      uploadFile(data)
        .then((res) => {
          // setLoading(false);
          console.log(res, "===---===");
          onChange([
            ...(value || []),
            {
              url: res.url,
              name: res?.url?.substring(res?.url?.lastIndexOf("/") + 1),
            },
          ]);
          // onSuccess(res.url);
        })
        .catch((err) => {
          onError(err);
        });

      return {
        abort() {
          console.log("upload progress is aborted.");
        },
      };
    },
    onRemove: (e) => {
      console.log(e, value, "123");

      onChange(value.filter((x) => x.url !== e.url));
    },
  };

  return (
    <div>
      <Upload {...uploadProps}>
        <Button icon={<UploadOutlined />}>上传文件</Button>
      </Upload>

      {/* {value &&
        preview &&
        (typeof preview === "function" ? (
          preview(value)
        ) : multiple ? (
          value?.map((x) => {
            return (
              <div style={{ marginTop: "0.7em" }} key={`${x?.fileAddr}`}>
                <a
                  href={`${x?.fileAddr}`}
                  download

                >
                  {x?.fileAddr?.substring(x?.fileAddr?.lastIndexOf("/") + 1)}
                </a>
              </div>
            );
          })
        ) : (
          <div style={{ marginTop: "1em" }}>
            <a
              href={`${value}`}
              download

            >
              {value?.substring(value?.lastIndexOf("/") + 1)}
            </a>
          </div>
        ))} */}
    </div>
  );
};
