import { addDish } from '@/services/dish';
import { ProForm, ProFormSelect, ProFormText, ProFormMoney } from '@ant-design/pro-components';
import { useNavigate, useSearchParams } from 'react-router-dom';
import { Row, Col, Space } from 'antd';
import { useEffect, useRef, useState, useMemo } from 'react';
import UploadFile from '@/components/UploadFile';
import Wangeditor from "@/components/Wangeditor";
import { floatMultiply, floatDivide } from "@/utils/float";

export default (props) => {
  const [searchParams] = useSearchParams();
  const id = searchParams.get('id');
  const navigate = useNavigate();

  const formRef = useRef();

  useEffect(() => {
    if (props.dish) {
      formRef.current.setFieldsValue({ ...props.dish, price: floatDivide(props.dish.price, 100) });
    }
  }, [props.dish]);

  const onFinish = async (values) => {
    addDish({ ...values, price: floatMultiply(values.price, 100), id }).then((res) => {
      props.onFinish(res);
    });

    return false;
  };

  return (
    <ProForm
      formRef={formRef}
      layout={'horizontal'}
      labelCol={{ span: 4 }}
      wrapperCol={{ span: 20 }}
      onFinish={onFinish}
      initialValues={{ type: '1', state: '1' }}
      submitter={{
        searchConfig: {
          resetText: '返回',
        },
        onReset: () => navigate(-1),
        render: (props, doms) => {
          return (
            <Row>
              <Col span={8} offset={8}>
                <Space>{doms}</Space>
              </Col>
            </Row>
          );
        },
      }}
    >
      <ProFormText
        name="name"
        label="名称"
        placeholder="请输入菜肴名称"
        rules={[{ required: true, message: '请输入菜肴名称' }]}
      />
      <ProFormText
        name="unit"
        label="单位"
        placeholder="请输入菜肴单位"
        rules={[{ required: true, message: '请输入菜肴单位' }]}
      />
      <ProFormMoney
        name="price"
        label="价格"
        rules={[{ required: true, message: '请输入菜肴价格' }]}
      />
      <ProFormSelect
        mode="multiple"
        name="ingredientsIdList"
        label="食材"
        placeholder="请选择包含食材"
        options={props.foodDict}
        onChange={props.onIngredientsChange}
      />
      <ProForm.Item name="thumb" label="图片">
        <UploadFile preview={true} />
      </ProForm.Item>
      <ProForm.Item name="content" label="做法">
        <Wangeditor></Wangeditor>
      </ProForm.Item>
    </ProForm>
  );
};
