import {
  PageContainer,
  ProForm,
  ProFormSelect,
  ProFormText,
  ProFormDateRangePicker,
} from "@ant-design/pro-components";
import { useNavigate, useSearchParams } from "react-router-dom";
import { Card, Col, Row, Space } from "antd";
import { useEffect, useRef } from "react";
import {
  gettCooperationUnitsDetail,
  savetCooperationUnits,
  updatetCooperationUnits,
} from "@/services/cooperationUnits";
import UploadFileList from "@/components/UploadFileList";

export default (props) => {
  const [searchParams] = useSearchParams();
  const id = searchParams.get("id");
  const navigate = useNavigate();

  const formRef = useRef();
  useEffect(() => {
    if (id) {
      gettCooperationUnitsDetail(id).then((res) => {
        formRef.current.setFieldsValue({
          ...res,
          timeRange: [res.startDate, res.endDate],
          orgType: res?.orgType?.split(","),
          fileList:
            res?.fileList?.map((x) => ({
              url: x.fileAddr,
              name: x.fileName,
              uid: x.id,
              ...x,
            })) || null,
        });
      });
    }
  }, [id]);

  const onFinish = async (values) => {

    const { timeRange = [], ...otherValues } = values;

    savetCooperationUnits({
      ...otherValues,

      orgType: values.orgType ? values.orgType?.join(",") : null,
      startDate: timeRange[0] ? timeRange[0] : null,
      endDate: timeRange[1] ? timeRange[1] : null,
      fileList:
        values?.fileList?.length > 0
          ? values?.fileList?.map((x) => ({
              fileName: x?.name,
              fileAddr: x?.url,
              id:x.id||null,
              orgId:id ? Number(id) : null,
            }))
          : null,
      id: id ? Number(id) : null,
    }).then((res) => {
      navigate(-1);
    });
  };

  return (
    <PageContainer>
      <Card>
        <ProForm
          formRef={formRef}
          layout={"horizontal"}
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 12 }}
          onFinish={onFinish}
          initialValues={{ status: 0 }}
          submitter={{
            searchConfig: {
              resetText: "返回",
            },
            onReset: () => navigate(-1),
            render: (props, doms) => {
              return (
                <Row>
                  <Col span={8} offset={8}>
                    <Space>{doms}</Space>
                  </Col>
                </Row>
              );
            },
          }}
        >
          <ProFormText
            name="name"
            label="机构名称"
            width={460}
            rules={[{ required: true, message: "请输入机构名称" }]}
          />
          <ProFormText
            name="businessLicense"
            label="工商注册证号"
            width={460}
          />
          <ProFormText name="hygieneLicense" label="卫生许可证号" width={460} />

          <ProFormText name="contacts" label="联系人" width={460} />
          <ProFormText name="phone" label="联系电话" width={460} />

          <ProFormDateRangePicker
            name="timeRange"
            label="签约时间"
            width={460}
          />
          <ProFormSelect
            width={460}
            name="orgType"
            label="机构类别"
            fieldProps={{
              mode: "tags",
              options: [
                "生鲜蔬菜类",
                "米面粮油类",
                "饮食类",
                "饮水类",
                "住宿类",
                "物资代储类",
                "医疗救助类",
                "油料类",
                "道路施救类",
              ],
            }}
          />
          <ProFormText
            name="dietDaily"
            label="单日机构内膳食供应能力(人次)"
            width={460}
          />
          <ProFormText
            name="dietSingle"
            label="单次机构内膳食供应能力(人)"
            width={460}
          />
          <ProFormText
            name="dietRemoteDaily"
            label="单日远程膳食供应能力(人次)"
            width={460}
          />
          <ProFormText
            name="dietRemoteSingle"
            label="单次远程膳食供应能力(人)"
            width={460}
          />
          <ProFormText
            name="stayCapability"
            label="机构内住宿供应能力(人)"
            width={460}
          />
          <ProForm.Item name="fileList" label="文件">
            <UploadFileList preview={true} multiple={true}></UploadFileList>
          </ProForm.Item>
        </ProForm>
      </Card>
    </PageContainer>
  );
};
