import React from 'react';
import * as echarts from 'echarts/core';
import icon from '@/assets/images/statistic/任务统计.png';
import Chart from '@/components/chart';
import { getStoreCosts } from '@/services/statis';
import StatisCard from './StatisCard';
import Filter from './Filter';

export default (props) => {

  const [filter, setFilter] = React.useState();
  const [option, setOption] = React.useState({});
  // const option = getOption(["1月", "2月", "3月", "4月", "5月", "6月", "7月", "8月", "9月", "10月", "11月", "12月"], [0, 0, 0, 0, 0, 0, 8, 9, 10, 1, 1, 6])

  React.useEffect(() => {
    if (filter) {
      getStoreCosts(filter).then(res => {
        const { purchase, taskCosts } = res;

        const keys = (purchase || []).map(x => x.dt);
        const data1 = (purchase || []).map(x => x.price / 100); // 数据返回的单位是 分
        const data2 = (taskCosts || []).map(x => x.price / 100);
  
        const opt = getOption(keys, data1, data2);
        const dataZoom = keys.length > 31 ? { show: true, height: 20, bottom: 6 } : { show: false };
  
        setOption({ ...opt, dataZoom });
      });
    }
  }, [filter]);

  return (
    <StatisCard
      title="成本分析"
      icon={icon}
      extra={<Filter onChange={setFilter} />}
    >
      <Chart option={option} style={{ height: '300px' }} />
    </StatisCard>
  )
}

function getOption(xAxisData, data1, data2) {
  var axisLabel = {
    fontSize: 14,
    color: 'rgba(255,255,255, .6)',
  };
  var lineStyle = {
    color: 'rgba(255,255,255, .16)',
    type: 'dashed'
  };

  return {
    tooltip : {
      trigger: 'axis',
      axisPointer : {
        type : 'shadow'
      },
      valueFormatter: v => `￥ ${v}`
    },
    xAxis: {
      type: 'category',
      axisLabel: { ...axisLabel, rotate: 45 },
      axisLine: {
        show: true,
        lineStyle: lineStyle
      },
      data: xAxisData
    },
    yAxis: [
      {
        type: 'value',
        axisLabel: axisLabel,
        axisLine: {
          show: true,
          lineStyle: lineStyle
        },
        splitLine: {
          lineStyle: lineStyle
        },
      },
    ],
    // dataZoom: [
    //   {
    //     show: true,
    //   }
    // ],
    grid: {
      top: 20,
      left: 50,
      right: 20,
      bottom: 100,
    },
    series: [
      {
        name: '用料成本',
        data: data1,
        type: 'line',
        smooth: true,
        itemStyle: {
          color: '#1EAED1'
        }
      },
      {
        name: '采购成本',
        data: data2,
        type: 'line',
        smooth: true,
        itemStyle: {
          color: '#6F39B9'
        }
      }
    ]
  }
}
