import React from 'react';
import icon from '@/assets/images/statistic/社会保障机构分类统计.png';
import Chart from '@/components/chart';
import { getStoreType } from '@/services/statis';
import StatisCard from './StatisCard';
import Filter from './Filter';

export default (props) => {

  const [filter, setFilter] = React.useState();
  const [option, setOption] = React.useState({});

  React.useEffect(() => {
    if (filter) {
      getStoreType(filter).then(res => {
        const keys = (res || []).map(x => x.name);
        const vals = (res || []).map(x => x.cnt);
        
        const dataZoom = res.length > 31 ? { show: true, height: 20, bottom: 6 } : { show: false };
        const opt = getOption(keys, vals);

        setOption({ ...opt, dataZoom });
      });
    }
  }, [filter]);

  return (
    <StatisCard
      title="物资分析"
      icon={icon}
      extra={<Filter hideUnit onChange={setFilter} />}
    >
      <Chart option={option} style={{ height: '300px' }} />
    </StatisCard>
  )
}

function getOption(xAxisData, seriesData) {
  var axisLabel = {
    fontSize: 14,
    color: 'rgba(255,255,255, .6)'
  };
  var lineStyle = {
    color: 'rgba(255,255,255, .16)',
    type: 'dashed'
  };

  return {
    xAxis: {
      type: 'category',
      axisLabel: Object.assign({
        rotate: 45
      }, axisLabel),
      axisLine: {
        show: true,
        lineStyle: lineStyle
      },
      data: xAxisData
    },
    yAxis: {
      axisLabel: axisLabel,
      axisLine: {
        show: true,
        lineStyle: lineStyle
      },
      splitLine: {
        lineStyle: lineStyle
      },
      type: 'value'
    },
    tooltip : {
      trigger: 'axis',
      axisPointer : {
        type : 'shadow'
      }
    },
    grid: {
      top: 20,
      left: 50,
      right: 20,
      bottom: 70,
    },
    color: ['#9242D1'],
    animationEasing: 'elasticOut',
    series: [
      {
        data: seriesData,
        type: 'pictorialBar',
        barWidth: 16,
        symbol: 'rect',
        symbolRepeat: true,
        animationDuration: 6000,
        animationDelay: function (dataIndex, params) {
          return params.index * 30;
        }
      }
    ]
  }
}
